@@ -1,5 +1,5 @@
 # mt-aws-glacier - Amazon Glacier sync client
-# Copyright (C) 2012-2014  Victor Efimov
+# Copyright (C) 2012-2013  Victor Efimov
 # http://mt-aws.com (also http://vs-dev.com) vs@vs-dev.com
 # License: GPLv3
 #
@@ -20,7 +20,7 @@
 
 package App::MtAws::Glacier::Inventory::CSV;
 
-our $VERSION = '1.114_2';
+our $VERSION = '1.103';
 
 use strict;
 use warnings;
@@ -31,6 +31,14 @@ use Carp;
 use App::MtAws::Glacier::Inventory ();
 use base q{App::MtAws::Glacier::Inventory};
 
+our %field_re = (
+	ArchiveId => '[A-Za-z0-9_-]+',
+	ArchiveDescription => '.*?',
+	CreationDate => '[^,]+?',
+	Size => '[^,]+?',
+	SHA256TreeHash => '[^,]+?',
+);
+
 sub new
 {
 	my $class = shift;
@@ -39,11 +47,20 @@ sub new
 	$self;
 }
 
+sub _unescape
+{
+	return unless $_[0] =~ /^\"/;
+	$_[0] =~ s/^\"//;
+	$_[0] =~ s/\"$//;
+	$_[0] =~ s/\\(.)/$1/g;
+}
+
+
 sub _parse
 {
 	my ($self) = @_;
 
-	# Text::CSV with below options does not seem to work for our case
+	# Text::CSV with belo options does not seem to work for our case
 	# ( { binary => 1 , allow_whitespace => 1, quote_char => '"', allow_loose_quotes => 1, escape_char => "\\", auto_diag=>1} )
 	# because Amazon CSV is buggy https://forums.aws.amazon.com/thread.jspa?threadID=141807&tstart=0
 
@@ -53,40 +70,18 @@ sub _parse
 	while (${$self->{rawdata}} =~ /^(.*?)\r?$/gsm) {
 		my $line = $1;
 		if(!defined $re) {
-			@fields = split /,/, $line;
-			for (@fields) {
-				s/^\"//;
-				s/\"$//;
-			}
-			my $re_s .= join(',', map {
-				qr{
-					(
-						([^\\\"\,]*?)|
-						(?:\"(
-							(?:\\\"|\\|.)*)
-						\")
-					)
-				}x;
-
-			} 1..@fields);
-			$re = qr/^$re_s$/;
-
+			@fields = split /\s*,\s*/, $line;
+			confess "Bad CSV header [$line]" unless
+				join(',', sort @fields) eq
+				join(',', sort qw/ArchiveId ArchiveDescription CreationDate Size SHA256TreeHash/);
+			_unescape($_) for (@fields);
+			my $re_str = join(',', map { "\\s*($_)\\s*" } map { $field_re{$_} or confess } @fields);
+			$re = qr/^$re_str$/;
 		} else {
-			my @x = $line =~ /$re/xm or confess "Bad CSV line [$line]";;
 			my %data;
-			@data{@fields} = map {
-				if (defined $x[$_*3+2]) {
-					my $s = $x[$_*3+2];
-					$s =~ s/\\"/"/g;
-					$s;
-				} elsif (defined $x[$_*3+1]) {
-					$x[$_*3+1];
-				} else {
-					confess;
-				}
-			} (0..$#fields);
+			@data{@fields} = $line =~ $re or confess "Bad CSV line [$line]";
+			_unescape($data{$_}) for (@fields);
 			push @records, \%data;
-
 		}
 	}
 	$self->{data} = { ArchiveList => \@records };
